"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
const _react = /*#__PURE__*/ _interop_require_wildcard(require("react"));
const _fieldeditortestutils = require("@contentful/field-editor-test-utils");
const _react1 = require("@testing-library/react");
require("@testing-library/jest-dom/extend-expect");
const _UrlEditor = require("./UrlEditor");
function _getRequireWildcardCache(nodeInterop) {
    if (typeof WeakMap !== "function") return null;
    var cacheBabelInterop = new WeakMap();
    var cacheNodeInterop = new WeakMap();
    return (_getRequireWildcardCache = function(nodeInterop) {
        return nodeInterop ? cacheNodeInterop : cacheBabelInterop;
    })(nodeInterop);
}
function _interop_require_wildcard(obj, nodeInterop) {
    if (!nodeInterop && obj && obj.__esModule) {
        return obj;
    }
    if (obj === null || typeof obj !== "object" && typeof obj !== "function") {
        return {
            default: obj
        };
    }
    var cache = _getRequireWildcardCache(nodeInterop);
    if (cache && cache.has(obj)) {
        return cache.get(obj);
    }
    var newObj = {
        __proto__: null
    };
    var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;
    for(var key in obj){
        if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) {
            var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;
            if (desc && (desc.get || desc.set)) {
                Object.defineProperty(newObj, key, desc);
            } else {
                newObj[key] = obj[key];
            }
        }
    }
    newObj.default = obj;
    if (cache) {
        cache.set(obj, newObj);
    }
    return newObj;
}
(0, _react1.configure)({
    testIdAttribute: 'data-test-id'
});
describe('UrlEditor', ()=>{
    afterEach(_react1.cleanup);
    it('renders without crashing', ()=>{
        const [field] = (0, _fieldeditortestutils.createFakeFieldAPI)();
        (0, _react1.render)(/*#__PURE__*/ _react.createElement(_UrlEditor.UrlEditor, {
            field: field,
            isInitiallyDisabled: false
        }));
    });
    it('reads initial value from field.getValue', ()=>{
        const initialValue = 'initial-value';
        const [field] = (0, _fieldeditortestutils.createFakeFieldAPI)((field)=>{
            return {
                ...field,
                id: 'field-id',
                getValue: ()=>{
                    return initialValue;
                }
            };
        });
        const { getByTestId } = (0, _react1.render)(/*#__PURE__*/ _react.createElement(_UrlEditor.UrlEditor, {
            field: field,
            isInitiallyDisabled: false
        }));
        expect(getByTestId('cf-ui-text-input')).toHaveValue(initialValue);
    });
    it('calls field.setValue when user types and calls field.removeValue when user clears the input', async ()=>{
        const [field] = (0, _fieldeditortestutils.createFakeFieldAPI)((field)=>{
            jest.spyOn(field, 'setValue');
            jest.spyOn(field, 'removeValue');
            return {
                ...field,
                id: 'field-id'
            };
        });
        const { getByTestId } = (0, _react1.render)(/*#__PURE__*/ _react.createElement(_UrlEditor.UrlEditor, {
            field: field,
            isInitiallyDisabled: false
        }));
        const $input = getByTestId('cf-ui-text-input');
        expect($input).toHaveValue('');
        _react1.fireEvent.change($input, {
            target: {
                value: 'new-value'
            }
        });
        await (0, _react1.waitFor)(()=>{
            expect($input).toHaveValue('new-value');
            expect(field.setValue).toHaveBeenCalledTimes(1);
            expect(field.setValue).toHaveBeenLastCalledWith('new-value');
        });
        _react1.fireEvent.change($input, {
            target: {
                value: ''
            }
        });
        await (0, _react1.waitFor)(()=>{
            expect($input).toHaveValue('');
            expect(field.removeValue).toHaveBeenCalledTimes(1);
            expect(field.removeValue).toHaveBeenLastCalledWith();
        });
    });
    it('gives an ability to render custom preview', ()=>{
        const initialValue = 'initial-value';
        const [field] = (0, _fieldeditortestutils.createFakeFieldAPI)((field)=>{
            return {
                ...field,
                id: 'field-id',
                getValue: ()=>{
                    return initialValue;
                }
            };
        });
        const { getByTestId, getByText } = (0, _react1.render)(/*#__PURE__*/ _react.createElement(_UrlEditor.UrlEditor, {
            field: field,
            isInitiallyDisabled: false
        }, ({ value })=>{
            return /*#__PURE__*/ _react.createElement("div", null, "Custom preview: ", value);
        }));
        const $input = getByTestId('cf-ui-text-input');
        expect($input).toHaveValue(initialValue);
        expect(getByText('Custom preview: initial-value')).toBeInTheDocument();
        _react1.fireEvent.change($input, {
            target: {
                value: 'new-value'
            }
        });
        expect(getByText('Custom preview: new-value')).toBeInTheDocument();
    });
});
